@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,15 +19,11 @@
 
 #include "gravatarconfigwidgettest.h"
 #include "../src/widgets/gravatarconfigwidget.h"
-#include <QSpinBox>
 #include <QCheckBox>
 #include <qtest.h>
-#include <QLabel>
 #include <QPushButton>
 #include <qtestmouse.h>
 #include <QSignalSpy>
-#include <QGroupBox>
-#include <QStyleOption>
 
 GravatarConfigWidgetTest::GravatarConfigWidgetTest(QObject *parent)
     : QObject(parent)
