@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -49,14 +49,6 @@ void GravatarDownloadPixmapWidgetTest::shouldHaveDefaultValue()
 
     QLabel *resultLabel = w.findChild<QLabel *>(QStringLiteral("resultlabel"));
     QVERIFY(resultLabel);
-
-    QCheckBox *useLibravatar = w.findChild<QCheckBox *>(QStringLiteral("uselibravatar"));
-    QVERIFY(useLibravatar);
-    QVERIFY(!useLibravatar->isChecked());
-
-    QCheckBox *fallBackGravatar = w.findChild<QCheckBox *>(QStringLiteral("fallbackgravatar"));
-    QVERIFY(fallBackGravatar);
-    QVERIFY(!fallBackGravatar->isChecked());
 }
 
 void GravatarDownloadPixmapWidgetTest::shouldChangeButtonEnableState()
