@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -18,8 +18,8 @@
 */
 
 #include "gravatarconfiguresettingsdialog.h"
+#include "gravatarconfiguresettingswidget.h"
 #include "misc/gravatarcache.h"
-#include "gravatarsettings.h"
 #include "PimCommon/ConfigureImmutableWidgetUtils"
 
 #include <KLocalizedString>
@@ -31,6 +31,7 @@
 #include <QPushButton>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
+#include "gravatarsettings.h"
 using namespace Gravatar;
 using namespace PimCommon::ConfigureImmutableWidgetUtils;
 
@@ -39,7 +40,9 @@ GravatarConfigureSettingsDialog::GravatarConfigureSettingsDialog(QWidget *parent
 {
     setWindowTitle(i18n("Configure Gravatar"));
     QVBoxLayout *topLayout = new QVBoxLayout(this);
+    topLayout->setObjectName(QStringLiteral("toplayout"));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults, this);
+    buttonBox->setObjectName(QStringLiteral("buttonbox"));
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &GravatarConfigureSettingsDialog::save);
@@ -47,40 +50,9 @@ GravatarConfigureSettingsDialog::GravatarConfigureSettingsDialog(QWidget *parent
     connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, this, &GravatarConfigureSettingsDialog::slotRestoreDefault);
     okButton->setDefault(true);
 
-    mUseDefaultPixmap = new QCheckBox(i18n("Use Default Image"), this);
-    mUseDefaultPixmap->setObjectName(QStringLiteral("usedefaultimage"));
-    topLayout->addWidget(mUseDefaultPixmap);
-
-    QHBoxLayout *cacheSizeLayout = new QHBoxLayout;
-    topLayout->addLayout(cacheSizeLayout);
-    QLabel *lab = new QLabel(i18n("Gravatar Cache Size:"), this);
-    lab->setObjectName(QStringLiteral("gravatarcachesizelabel"));
-    cacheSizeLayout->addWidget(lab);
-
-    mGravatarCacheSize = new KPluralHandlingSpinBox(this);
-    mGravatarCacheSize->setMinimum(1);
-    mGravatarCacheSize->setMaximum(9999);
-    mGravatarCacheSize->setSuffix(ki18ncp("add space before image", " image", " images"));
-    mGravatarCacheSize->setObjectName(QStringLiteral("gravatarcachesize"));
-    cacheSizeLayout->addWidget(mGravatarCacheSize);
-    cacheSizeLayout->addStretch();
-
-    KSeparator *separator = new KSeparator(this);
-    separator->setObjectName(QStringLiteral("separator"));
-    topLayout->addWidget(separator);
-
-    QHBoxLayout *buttonLayout = new QHBoxLayout;
-    topLayout->addLayout(buttonLayout);
-    mClearGravatarCache = new QPushButton(i18n("Clear Gravatar Cache"), this);
-    mClearGravatarCache->setObjectName(QStringLiteral("cleargravatarcachebutton"));
-    buttonLayout->addWidget(mClearGravatarCache);
-    buttonLayout->addStretch();
-
-    separator = new KSeparator(this);
-    separator->setObjectName(QStringLiteral("separator2"));
-    topLayout->addWidget(separator);
-
-    connect(mClearGravatarCache, &QAbstractButton::clicked, this, &GravatarConfigureSettingsDialog::slotClearGravatarCache);
+    mGravatarConfigureSettings = new GravatarConfigureSettingsWidget(this);
+    mGravatarConfigureSettings->setObjectName(QStringLiteral("gravatarconfiguresettings"));
+    topLayout->addWidget(mGravatarConfigureSettings);
     topLayout->addWidget(buttonBox);
     load();
 }
@@ -91,25 +63,17 @@ GravatarConfigureSettingsDialog::~GravatarConfigureSettingsDialog()
 
 void GravatarConfigureSettingsDialog::slotRestoreDefault()
 {
-    const bool bUseDefaults = Gravatar::GravatarSettings::self()->useDefaults(true);
-    load();
-    Gravatar::GravatarSettings::self()->useDefaults(bUseDefaults);
+    mGravatarConfigureSettings->load();
 }
 
 void GravatarConfigureSettingsDialog::save()
 {
-    saveCheckBox(mUseDefaultPixmap, Gravatar::GravatarSettings::self()->gravatarUseDefaultImageItem());
-    saveSpinBox(mGravatarCacheSize, Gravatar::GravatarSettings::self()->gravatarCacheSizeItem());
+    mGravatarConfigureSettings->save();
     accept();
 }
 
 void GravatarConfigureSettingsDialog::load()
 {
-    loadWidget(mUseDefaultPixmap, Gravatar::GravatarSettings::self()->gravatarUseDefaultImageItem());
-    loadWidget(mGravatarCacheSize, Gravatar::GravatarSettings::self()->gravatarCacheSizeItem());
+    mGravatarConfigureSettings->load();
 }
 
-void GravatarConfigureSettingsDialog::slotClearGravatarCache()
-{
-    Gravatar::GravatarCache::self()->clearAllCache();
-}
